package com.mall.coupon.controller;

import com.mall.coupon.domain.dto.HomeSubjectDto;
import com.mall.coupon.domain.entity.HomeSubject;
import com.mall.coupon.domain.vo.HomeSubjectVo;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.Valid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import com.mall.coupon.service.HomeSubjectService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】 前端控制器
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Tag(name = "首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】", description = "首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】相关接口")
@RestController
@RequestMapping("/api/coupon/home-subject")
@RequiredArgsConstructor
public class HomeSubjectController {

    private final HomeSubjectService homeSubjectService;

    @Operation(summary = "分页查询首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】", description = "分页首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】")
    @GetMapping("{page}/{limit}")
    public Result<PageResult<HomeSubjectVo>> getHomeSubjectPage(
            @Parameter(name = "page", description = "当前页", required = true)
            @PathVariable("page") Integer page,
            @Parameter(name = "limit", description = "每页记录数", required = true)
            @PathVariable("limit") Integer limit,
            HomeSubjectDto dto) {
        Page<HomeSubject> pageParams = new Page<>(page, limit);
        PageResult<HomeSubjectVo> pageResult = homeSubjectService.getHomeSubjectPage(pageParams, dto);
        return Result.success(pageResult);
    }

    @Operation(summary = "添加首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】", description = "添加首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】")
    @PostMapping()
    public Result<String> addHomeSubject(@Valid @RequestBody HomeSubjectDto dto) {
            homeSubjectService.addHomeSubject(dto);
        return Result.success(ResultCodeEnum.ADD_SUCCESS);
    }

    @Operation(summary = "更新首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】", description = "更新首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】")
    @PutMapping()
    public Result<String> updateHomeSubject(@Valid @RequestBody HomeSubjectDto dto) {
            homeSubjectService.updateHomeSubject(dto);
        return Result.success(ResultCodeEnum.UPDATE_SUCCESS);
    }

    @Operation(summary = "删除首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】", description = "删除首页专题表【jd首页下面很多专题，每个专题链接新的页面，展示专题商品信息】")
    @DeleteMapping()
    public Result<String> deleteHomeSubject(@RequestBody List<Long> ids) {
            homeSubjectService.deleteHomeSubject(ids);
        return Result.success(ResultCodeEnum.DELETE_SUCCESS);
    }
}