package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.CouponHistoryMapper;
import com.mall.coupon.service.CouponHistoryService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.CouponHistoryService;
import com.mall.coupon.domain.dto.CouponHistoryDto;
import com.mall.coupon.domain.entity.CouponHistory;
import com.mall.coupon.domain.vo.CouponHistoryVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 优惠券领取历史记录 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class CouponHistoryServiceImpl extends ServiceImpl<CouponHistoryMapper, CouponHistory> implements CouponHistoryService {

    /**
     * * 优惠券领取历史记录 服务实现类
     *
     * @param pageParams 优惠券领取历史记录分页查询page对象
     * @param dto        优惠券领取历史记录分页查询对象
     * @return 查询分页优惠券领取历史记录返回对象
     */
    @Override
    public PageResult<CouponHistoryVo> getCouponHistoryPage(Page<CouponHistory> pageParams, CouponHistoryDto dto) {
        IPage<CouponHistoryVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<CouponHistoryVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加优惠券领取历史记录
     *
     * @param dto 优惠券领取历史记录添加
     */
    @Override
    public void addCouponHistory(CouponHistoryDto dto) {
        CouponHistory couponHistory =new CouponHistory();
        BeanUtils.copyProperties(dto, couponHistory);
        save(couponHistory);
    }

    /**
     * 更新优惠券领取历史记录
     *
     * @param dto 优惠券领取历史记录更新
     */
    @Override
    public void updateCouponHistory(CouponHistoryDto dto) {
        CouponHistory couponHistory =new CouponHistory();
        BeanUtils.copyProperties(dto, couponHistory);
        updateById(couponHistory);
    }

    /**
     * 删除|批量删除优惠券领取历史记录
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteCouponHistory(List<Long> ids) {
        removeByIds(ids);
    }
}