package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.CouponMapper;
import com.mall.coupon.service.CouponService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.CouponService;
import com.mall.coupon.domain.dto.CouponDto;
import com.mall.coupon.domain.entity.Coupon;
import com.mall.coupon.domain.vo.CouponVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 优惠券信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class CouponServiceImpl extends ServiceImpl<CouponMapper, Coupon> implements CouponService {

    /**
     * * 优惠券信息 服务实现类
     *
     * @param pageParams 优惠券信息分页查询page对象
     * @param dto        优惠券信息分页查询对象
     * @return 查询分页优惠券信息返回对象
     */
    @Override
    public PageResult<CouponVo> getCouponPage(Page<Coupon> pageParams, CouponDto dto) {
        IPage<CouponVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<CouponVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加优惠券信息
     *
     * @param dto 优惠券信息添加
     */
    @Override
    public void addCoupon(CouponDto dto) {
        Coupon coupon =new Coupon();
        BeanUtils.copyProperties(dto, coupon);
        save(coupon);
    }

    /**
     * 更新优惠券信息
     *
     * @param dto 优惠券信息更新
     */
    @Override
    public void updateCoupon(CouponDto dto) {
        Coupon coupon =new Coupon();
        BeanUtils.copyProperties(dto, coupon);
        updateById(coupon);
    }

    /**
     * 删除|批量删除优惠券信息
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteCoupon(List<Long> ids) {
        removeByIds(ids);
    }
}