package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.CouponSpuCategoryRelationMapper;
import com.mall.coupon.service.CouponSpuCategoryRelationService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.CouponSpuCategoryRelationService;
import com.mall.coupon.domain.dto.CouponSpuCategoryRelationDto;
import com.mall.coupon.domain.entity.CouponSpuCategoryRelation;
import com.mall.coupon.domain.vo.CouponSpuCategoryRelationVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 优惠券分类关联 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class CouponSpuCategoryRelationServiceImpl extends ServiceImpl<CouponSpuCategoryRelationMapper, CouponSpuCategoryRelation> implements CouponSpuCategoryRelationService {

    /**
     * * 优惠券分类关联 服务实现类
     *
     * @param pageParams 优惠券分类关联分页查询page对象
     * @param dto        优惠券分类关联分页查询对象
     * @return 查询分页优惠券分类关联返回对象
     */
    @Override
    public PageResult<CouponSpuCategoryRelationVo> getCouponSpuCategoryRelationPage(Page<CouponSpuCategoryRelation> pageParams, CouponSpuCategoryRelationDto dto) {
        IPage<CouponSpuCategoryRelationVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<CouponSpuCategoryRelationVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加优惠券分类关联
     *
     * @param dto 优惠券分类关联添加
     */
    @Override
    public void addCouponSpuCategoryRelation(CouponSpuCategoryRelationDto dto) {
        CouponSpuCategoryRelation couponSpuCategoryRelation =new CouponSpuCategoryRelation();
        BeanUtils.copyProperties(dto, couponSpuCategoryRelation);
        save(couponSpuCategoryRelation);
    }

    /**
     * 更新优惠券分类关联
     *
     * @param dto 优惠券分类关联更新
     */
    @Override
    public void updateCouponSpuCategoryRelation(CouponSpuCategoryRelationDto dto) {
        CouponSpuCategoryRelation couponSpuCategoryRelation =new CouponSpuCategoryRelation();
        BeanUtils.copyProperties(dto, couponSpuCategoryRelation);
        updateById(couponSpuCategoryRelation);
    }

    /**
     * 删除|批量删除优惠券分类关联
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteCouponSpuCategoryRelation(List<Long> ids) {
        removeByIds(ids);
    }
}