package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.CouponSpuRelationMapper;
import com.mall.coupon.service.CouponSpuRelationService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.CouponSpuRelationService;
import com.mall.coupon.domain.dto.CouponSpuRelationDto;
import com.mall.coupon.domain.entity.CouponSpuRelation;
import com.mall.coupon.domain.vo.CouponSpuRelationVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 优惠券与产品关联 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class CouponSpuRelationServiceImpl extends ServiceImpl<CouponSpuRelationMapper, CouponSpuRelation> implements CouponSpuRelationService {

    /**
     * * 优惠券与产品关联 服务实现类
     *
     * @param pageParams 优惠券与产品关联分页查询page对象
     * @param dto        优惠券与产品关联分页查询对象
     * @return 查询分页优惠券与产品关联返回对象
     */
    @Override
    public PageResult<CouponSpuRelationVo> getCouponSpuRelationPage(Page<CouponSpuRelation> pageParams, CouponSpuRelationDto dto) {
        IPage<CouponSpuRelationVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<CouponSpuRelationVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加优惠券与产品关联
     *
     * @param dto 优惠券与产品关联添加
     */
    @Override
    public void addCouponSpuRelation(CouponSpuRelationDto dto) {
        CouponSpuRelation couponSpuRelation =new CouponSpuRelation();
        BeanUtils.copyProperties(dto, couponSpuRelation);
        save(couponSpuRelation);
    }

    /**
     * 更新优惠券与产品关联
     *
     * @param dto 优惠券与产品关联更新
     */
    @Override
    public void updateCouponSpuRelation(CouponSpuRelationDto dto) {
        CouponSpuRelation couponSpuRelation =new CouponSpuRelation();
        BeanUtils.copyProperties(dto, couponSpuRelation);
        updateById(couponSpuRelation);
    }

    /**
     * 删除|批量删除优惠券与产品关联
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteCouponSpuRelation(List<Long> ids) {
        removeByIds(ids);
    }
}