package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.MemberPriceMapper;
import com.mall.coupon.service.MemberPriceService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.MemberPriceService;
import com.mall.coupon.domain.dto.MemberPriceDto;
import com.mall.coupon.domain.entity.MemberPrice;
import com.mall.coupon.domain.vo.MemberPriceVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 商品会员价格 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class MemberPriceServiceImpl extends ServiceImpl<MemberPriceMapper, MemberPrice> implements MemberPriceService {

    /**
     * * 商品会员价格 服务实现类
     *
     * @param pageParams 商品会员价格分页查询page对象
     * @param dto        商品会员价格分页查询对象
     * @return 查询分页商品会员价格返回对象
     */
    @Override
    public PageResult<MemberPriceVo> getMemberPricePage(Page<MemberPrice> pageParams, MemberPriceDto dto) {
        IPage<MemberPriceVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<MemberPriceVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品会员价格
     *
     * @param dto 商品会员价格添加
     */
    @Override
    public void addMemberPrice(MemberPriceDto dto) {
        MemberPrice memberPrice =new MemberPrice();
        BeanUtils.copyProperties(dto, memberPrice);
        save(memberPrice);
    }

    /**
     * 更新商品会员价格
     *
     * @param dto 商品会员价格更新
     */
    @Override
    public void updateMemberPrice(MemberPriceDto dto) {
        MemberPrice memberPrice =new MemberPrice();
        BeanUtils.copyProperties(dto, memberPrice);
        updateById(memberPrice);
    }

    /**
     * 删除|批量删除商品会员价格
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteMemberPrice(List<Long> ids) {
        removeByIds(ids);
    }
}