package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.SkuLadderMapper;
import com.mall.coupon.service.SkuLadderService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.SkuLadderService;
import com.mall.coupon.domain.dto.SkuLadderDto;
import com.mall.coupon.domain.entity.SkuLadder;
import com.mall.coupon.domain.vo.SkuLadderVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 商品阶梯价格 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class SkuLadderServiceImpl extends ServiceImpl<SkuLadderMapper, SkuLadder> implements SkuLadderService {

    /**
     * * 商品阶梯价格 服务实现类
     *
     * @param pageParams 商品阶梯价格分页查询page对象
     * @param dto        商品阶梯价格分页查询对象
     * @return 查询分页商品阶梯价格返回对象
     */
    @Override
    public PageResult<SkuLadderVo> getSkuLadderPage(Page<SkuLadder> pageParams, SkuLadderDto dto) {
        IPage<SkuLadderVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SkuLadderVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品阶梯价格
     *
     * @param dto 商品阶梯价格添加
     */
    @Override
    public void addSkuLadder(SkuLadderDto dto) {
        SkuLadder skuLadder =new SkuLadder();
        BeanUtils.copyProperties(dto, skuLadder);
        save(skuLadder);
    }

    /**
     * 更新商品阶梯价格
     *
     * @param dto 商品阶梯价格更新
     */
    @Override
    public void updateSkuLadder(SkuLadderDto dto) {
        SkuLadder skuLadder =new SkuLadder();
        BeanUtils.copyProperties(dto, skuLadder);
        updateById(skuLadder);
    }

    /**
     * 删除|批量删除商品阶梯价格
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSkuLadder(List<Long> ids) {
        removeByIds(ids);
    }
}