package com.mall.coupon.service.impl;

import com.mall.coupon.mapper.SpuBoundsMapper;
import com.mall.coupon.service.SpuBoundsService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.mall.coupon.service.SpuBoundsService;
import com.mall.coupon.domain.dto.SpuBoundsDto;
import com.mall.coupon.domain.entity.SpuBounds;
import com.mall.coupon.domain.vo.SpuBoundsVo;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.common.domain.vo.result.Result;
import com.mall.common.domain.vo.result.ResultCodeEnum;

import java.util.List;

/**
 * <p>
 * 商品spu积分设置 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-06 11:15:40
 */
@Service
@Transactional
public class SpuBoundsServiceImpl extends ServiceImpl<SpuBoundsMapper, SpuBounds> implements SpuBoundsService {

    /**
     * * 商品spu积分设置 服务实现类
     *
     * @param pageParams 商品spu积分设置分页查询page对象
     * @param dto        商品spu积分设置分页查询对象
     * @return 查询分页商品spu积分设置返回对象
     */
    @Override
    public PageResult<SpuBoundsVo> getSpuBoundsPage(Page<SpuBounds> pageParams, SpuBoundsDto dto) {
        IPage<SpuBoundsVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<SpuBoundsVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品spu积分设置
     *
     * @param dto 商品spu积分设置添加
     */
    @Override
    public void addSpuBounds(SpuBoundsDto dto) {
        SpuBounds spuBounds =new SpuBounds();
        BeanUtils.copyProperties(dto, spuBounds);
        save(spuBounds);
    }

    /**
     * 更新商品spu积分设置
     *
     * @param dto 商品spu积分设置更新
     */
    @Override
    public void updateSpuBounds(SpuBoundsDto dto) {
        SpuBounds spuBounds =new SpuBounds();
        BeanUtils.copyProperties(dto, spuBounds);
        updateById(spuBounds);
    }

    /**
     * 删除|批量删除商品spu积分设置
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteSpuBounds(List<Long> ids) {
        removeByIds(ids);
    }
}