package com.mall.product.domain.dto;

import com.mall.common.domain.dto.valid.custom.ListValue;
import com.mall.common.domain.dto.valid.group.AddGroup;
import com.mall.common.domain.dto.valid.group.DeletedGroup;
import com.mall.common.domain.dto.valid.group.UpdateGroup;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.URL;

@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Schema(name = "BrandDTO对象", title = "品牌", description = "品牌的DTO对象")
public class BrandDto {

    @Schema(name = "brandId", title = "品牌id")
    @NotNull(message = "品牌id未传", groups = {UpdateGroup.class, DeletedGroup.class})
    private Long brandId;

    @Schema(name = "name", title = "品牌名")
    @NotBlank(message = "品牌名不能为空", groups = {AddGroup.class, UpdateGroup.class})
    private String name;

    @Schema(name = "logo", title = "品牌logo地址")
    @URL(message = "logo地址不合法", groups = {AddGroup.class, UpdateGroup.class})
    private String logo;

    @Schema(name = "descript", title = "介绍")
    private String descript;

    @Schema(name = "showStatus", title = "显示状态[0-不显示；1-显示]")
    @ListValue(vals = {0, 1}, groups = {AddGroup.class, UpdateGroup.class})
    private Integer showStatus;

    @Schema(name = "firstLetter", title = "检索首字母")
    private String firstLetter;

    @Schema(name = "sort", title = "排序")
    private Integer sort;

}