package com.mall.product.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.CategoryBrandRelationDto;
import com.mall.product.domain.entity.CategoryBrandRelationEntity;
import com.mall.product.domain.vo.CategoryBrandRelationVo;

import java.util.List;

/**
 * <p>
 * 品牌分类关联 服务类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
public interface CategoryBrandRelationService extends IService<CategoryBrandRelationEntity> {

    /**
     * 分页查询品牌分类关联
     *
     * @return {@link CategoryBrandRelationVo}
     */
    PageResult<CategoryBrandRelationVo> getCategoryBrandRelationPage(Page<CategoryBrandRelationEntity> pageParams, CategoryBrandRelationDto dto);

    /**
     * 添加品牌与分类的关联关系
     *
     * <p>实现逻辑：
     * 1. 根据品牌ID查询品牌信息，获取品牌名称
     * 2. 根据分类ID查询分类信息，获取分类名称
     * 3. 将品牌和分类的关联关系及冗余信息保存到关联表中
     *
     * <p>设计说明：
     * 采用冗余存储设计，在关联表中同时存储品牌名称和分类名称，
     * 避免多表关联查询，提升电商系统在大数据量场景下的查询性能
     *
     * @param dto 品牌分类关联数据 {@link CategoryBrandRelationDto}
     */
    void saveCategoryBrandRelation(CategoryBrandRelationDto dto);

    /**
     * 更新品牌分类关联
     *
     * @param dto {@link CategoryBrandRelationDto} 更新表单
     */
    void updateCategoryBrandRelation(CategoryBrandRelationDto dto);

    /**
     * 删除|批量删除品牌分类关联类型
     *
     * @param ids 删除id列表
     */
    void deleteCategoryBrandRelation(List<Long> ids);

    /**
     * 返回分类列表
     *
     * @param brandId 品牌id
     * @return 品牌关联所有分类列表
     */
    List<CategoryBrandRelationVo> getCategoryList(Long brandId);
}
