package com.mall.product.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.CategoryDto;
import com.mall.product.domain.entity.CategoryEntity;
import com.mall.product.domain.vo.CategoryVo;

import java.util.List;

/**
 * <p>
 * 商品三级分类 服务类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
public interface CategoryService extends IService<CategoryEntity> {

    /**
     * 分页查询商品三级分类
     *
     * @return {@link CategoryVo}
     */
    PageResult<CategoryVo> getCategoryPage(Page<CategoryEntity> pageParams, CategoryDto dto);

    /**
     * 添加商品三级分类
     *
     * @param dto {@link CategoryDto} 添加表单
     */
    void addCategory(CategoryDto dto);

    /**
     * 更新商品三级分类
     *
     * @param dto {@link CategoryDto} 更新表单
     */
    void updateCategory(CategoryDto dto);

    /**
     * 删除|批量删除商品三级分类类型
     *
     * @param ids 删除id列表
     */
    void deleteCategory(List<Long> ids);

    /**
     * 三级分类树型结构
     *
     * @return 树型结构的三级菜单
     */
    List<CategoryEntity> getCategoryTreeList();

    /**
     * 找到后代所有的路径
     *
     * @param catelogId 分类id
     * @return 后端所有的id
     */
    List<Long> findCatelogPath(Long catelogId);
}
