package com.mall.product.service.ext;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.product.domain.entity.CategoryEntity;
import com.mall.product.mapper.CategoryMapper;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CategoryServiceImplExt extends ServiceImpl<CategoryMapper, CategoryEntity> {

    /**
     * 递归组装树型结构
     *
     * @param categoryEntity     商品三级分类
     * @param categoryEntityList 商品三级分类列表
     * @return 树型结构菜单
     */
    public static List<CategoryEntity> getCategoryTreeChildrenList(CategoryEntity categoryEntity, List<CategoryEntity> categoryEntityList) {
        return categoryEntityList.stream()
                .filter(item -> item.getParentCid().equals(categoryEntity.getCatId()))
                .toList();
    }

    /**
     * 递归查询父级路径
     *
     * @param catelogId 分类id
     * @param paths     当前组装的路径
     * @return 后代所有的路径
     */
    public List<Long> findParentPath(Long catelogId, List<Long> paths) {
        paths.add(catelogId);
        CategoryEntity categoryEntity = getById(catelogId);
        if (!categoryEntity.getParentCid().equals(0L)) {
            findParentPath(categoryEntity.getParentCid(), paths);
        }

        return paths;
    }

}
