package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.AttrGroupDto;
import com.mall.product.domain.entity.AttrGroupEntity;
import com.mall.product.domain.vo.AttrGroupVo;
import com.mall.product.mapper.AttrGroupMapper;
import com.mall.product.service.AttrGroupService;
import com.mall.product.service.CategoryService;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 属性分组 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
public class AttrGroupServiceImpl extends ServiceImpl<AttrGroupMapper, AttrGroupEntity> implements AttrGroupService {

    private final CategoryService categoryService;

    public AttrGroupServiceImpl(CategoryService categoryService) {
        this.categoryService = categoryService;
    }

    /**
     * * 属性分组 服务实现类
     *
     * @param pageParams 属性分组分页查询page对象
     * @param dto        属性分组分页查询对象
     * @return 查询分页属性分组返回对象
     */
    @Override
    public PageResult<AttrGroupVo> getAttrGroupPage(Page<AttrGroupEntity> pageParams, AttrGroupDto dto) {
        IPage<AttrGroupVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<AttrGroupVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加属性分组
     *
     * @param dto 属性分组添加
     */
    @Override
    public void addAttrGroup(AttrGroupDto dto) {
        AttrGroupEntity attrGroupEntity = new AttrGroupEntity();
        BeanUtils.copyProperties(dto, attrGroupEntity);
        save(attrGroupEntity);
    }

    /**
     * 更新属性分组
     *
     * @param dto 属性分组更新
     */
    @Override
    public void updateAttrGroup(AttrGroupDto dto) {
        AttrGroupEntity attrGroupEntity = new AttrGroupEntity();
        BeanUtils.copyProperties(dto, attrGroupEntity);
        updateById(attrGroupEntity);
    }

    /**
     * 删除|批量删除属性分组
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteAttrGroup(List<Long> ids) {
        removeByIds(ids);
    }

    /**
     * 根据id查询详情
     *
     * @param attrGroupId 分组id
     * @return 属性分组
     */
    @Override
    public AttrGroupVo getAttrGroupById(Long attrGroupId) {
        AttrGroupEntity attrGroupEntity = getById(attrGroupId);
        Long catelogId = attrGroupEntity.getCatelogId();

        // 找到后代所有的路径
        List<Long> catelogIds = categoryService.findCatelogPath(catelogId);

        AttrGroupVo attrGroupVo = new AttrGroupVo();
        BeanUtils.copyProperties(attrGroupEntity, attrGroupVo);
        attrGroupVo.setCatelogPaths(catelogIds);
        return attrGroupVo;
    }
}