package com.mall.product.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mall.common.domain.vo.result.PageResult;
import com.mall.product.domain.dto.CategoryDto;
import com.mall.product.domain.entity.CategoryEntity;
import com.mall.product.domain.vo.CategoryVo;
import com.mall.product.mapper.CategoryMapper;
import com.mall.product.service.CategoryService;
import com.mall.product.service.ext.CategoryServiceImplExt;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import static com.mall.product.service.ext.CategoryServiceImplExt.getCategoryTreeChildrenList;

/**
 * <p>
 * 商品三级分类 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2025-07-04 14:05:53
 */
@Service
@Transactional
@RequiredArgsConstructor
public class CategoryServiceImpl extends ServiceImpl<CategoryMapper, CategoryEntity> implements CategoryService {

    private final CategoryServiceImplExt categoryServiceImplExt;

    /**
     * * 商品三级分类 服务实现类
     *
     * @param pageParams 商品三级分类分页查询page对象
     * @param dto        商品三级分类分页查询对象
     * @return 查询分页商品三级分类返回对象
     */
    @Override
    public PageResult<CategoryVo> getCategoryPage(Page<CategoryEntity> pageParams, CategoryDto dto) {
        IPage<CategoryVo> page = baseMapper.selectListByPage(pageParams, dto);

        return PageResult.<CategoryVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加商品三级分类
     *
     * @param dto 商品三级分类添加
     */
    @Override
    public void addCategory(CategoryDto dto) {
        CategoryEntity categoryEntity = new CategoryEntity();
        BeanUtils.copyProperties(dto, categoryEntity);
        save(categoryEntity);
    }

    /**
     * 更新商品三级分类
     *
     * @param dto 商品三级分类更新
     */
    @Override
    public void updateCategory(CategoryDto dto) {
        CategoryEntity categoryEntity = new CategoryEntity();
        BeanUtils.copyProperties(dto, categoryEntity);
        updateById(categoryEntity);
    }

    /**
     * 删除|批量删除商品三级分类
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteCategory(List<Long> ids) {
        // baseMapper.removeByIdsByIds(ids);
        removeByIds(ids);
    }

    /**
     * 三级分类树型结构
     *
     * @return 树型结构的三级菜单
     */
    @Override
    public List<CategoryEntity> getCategoryTreeList() {
        List<CategoryEntity> categoryEntityList = list();
        return categoryEntityList.stream().filter(category -> category.getParentCid().equals(0L))
                .peek(category -> category.setChildren(getCategoryTreeChildrenList(category, categoryEntityList)))
                .sorted(Comparator.comparing(CategoryEntity::getSort))
                .toList();
    }

    /**
     * 找到后代所有的路径
     *
     * @param catelogId 分类id
     * @return 后端所有的id
     */
    @Override
    public List<Long> findCatelogPath(Long catelogId) {
        List<Long> paths = new ArrayList<>();
        List<Long> longList = categoryServiceImplExt.findParentPath(catelogId, paths);

        // 饭庄当前数组
        Collections.reverse(longList);

        return longList;
    }

}